@@ -16,6 +16,7 @@ class StoreOutcome(Enum):
 
 
 class AbstractBackend(metaclass=abc.ABCMeta):
+    client = None
 
     @abc.abstractmethod
     def __init__(self, logger: logging.Logger | None = None):
@@ -47,19 +48,22 @@ class AbstractBackend(metaclass=abc.ABCMeta):
         pass
 
     @abc.abstractmethod
-    def versions(self, bucket_name: str, remote_key: str = '') -> list[dict]:
+    def versions(self, bucket_name: str, remote_key: str = '',
+                 raise_on_error: bool = False) -> list[dict]:
         """
         List the versions of an object
 
         :param remote_key: the remote key (filename) to list
         :param bucket_name: the remote bucket name
+        :param raise_on_error: whether to raise underlying exceptions if there is a client error
         :return: a list of dictionaries containing 'version_id', 'last_modified', and 'size'
         """
         pass
 
     @abc.abstractmethod
     def store_object(self, local_file: Path, bucket_name: str,
-                     remote_key: str, check_identical: bool) -> StoreOutcome:
+                     remote_key: str, check_identical: bool,
+                     raise_on_error: bool = False) -> StoreOutcome:
         """
         Store an object remotely
 
@@ -67,26 +71,30 @@ class AbstractBackend(metaclass=abc.ABCMeta):
         :param bucket_name: the remote bucket name
         :param remote_key: the remote key (filename) of the object
         :param check_identical: whether to check if the last version is already the same as this version
+        :param raise_on_error: whether to raise underlying exceptions if there is a client error
         :return: a response enum StoreOutcome
         """
         pass
 
     @abc.abstractmethod
     def get_object(self, bucket_name: str, remote_key: str,
-                   version_id: str) -> bytes | None:
+                   version_id: str,
+                   raise_on_error: bool = False) -> bytes | None:
         """
         Retrieve an object from the remote store as bytes
 
         :param bucket_name: the remote bucket name
         :param remote_key: the remote key (filename) of the object
         :param version_id: the version ID to fetch
+        :param raise_on_error: whether to raise underlying exceptions if there is a client error
         :return: the bytes of the retrieved object
         """
         pass
 
     @abc.abstractmethod
     def download_object(self, local_file: Path, bucket_name: str,
-                        remote_key: str, version_id: str) -> bool:
+                        remote_key: str, version_id: str,
+                        raise_on_error: bool = False) -> bool:
         """
         Retrieve an object from the remote store and save it to a file
 
@@ -94,6 +102,7 @@ class AbstractBackend(metaclass=abc.ABCMeta):
         :param bucket_name: the remote bucket name
         :param remote_key: the remote key (filename) of the object
         :param version_id: the version ID to fetch
+        :param raise_on_error: whether to raise underlying exceptions if there is a client error
         :return: a true/false boolean of success
         """
         pass
@@ -114,7 +123,8 @@ class BackendFactory:
 
         # see if there's a list of backends in the settings file
         # if there is, use it
-        backends = ['caretaker.backend.backends.s3']
+        backends = ['caretaker.backend.backends.s3',
+                    'caretaker.backend.backends.local']
 
         if hasattr(settings, 'CARETAKER_BACKENDS') and \
                 settings.CARETAKER_BACKENDS:
@@ -149,5 +159,5 @@ class BackendFactory:
         return None
 
 
-class BackendNotFoundError (Exception):
+class BackendNotFoundError(Exception):
     pass
