@@ -23,7 +23,7 @@ def command(remote_key: str, local_file: str, backup_version: str,
     """
     Saves BACKUP-VERSION of REMOTE-KEY into LOCAL-FILE
     """
-    logger = log.get_logger('caretaker')
+    logger = log.get_logger('')
 
     try:
         frontend, backend = FrontendFactory.get_frontend_and_backend(
@@ -41,3 +41,5 @@ def command(remote_key: str, local_file: str, backup_version: str,
         logger.error('Unable to find a valid backend')
     except FrontendNotFoundError:
         logger.error('Unable to find a valid frontend')
+    except FileNotFoundError:
+        logger.error('Unable to write to {}'.format(local_file))
