@@ -21,7 +21,7 @@ def command(remote_key: str, local_file: str, backend_name: str,
     """
     Pushes LOCAL-FILE to the latest version of REMOTE-KEY
     """
-    logger = log.get_logger('caretaker')
+    logger = log.get_logger('')
 
     try:
         frontend, backend = FrontendFactory.get_frontend_and_backend(
@@ -39,3 +39,5 @@ def command(remote_key: str, local_file: str, backend_name: str,
         logger.error('Unable to find a valid backend')
     except FrontendNotFoundError:
         logger.error('Unable to find a valid frontend')
+    except FileNotFoundError:
+        logger.error('Unable to read from {}'.format(local_file))
