@@ -3,6 +3,7 @@ import logging
 
 import boto3
 
+from django.conf import settings
 from caretaker.backend.abstract_backend import BackendFactory
 from caretaker.frontend.abstract_frontend import FrontendFactory
 from caretaker.tests.caretaker_main_test import AbstractCaretakerTest
@@ -10,9 +11,28 @@ from caretaker.utils import log
 
 
 class AbstractDjangoS3Test(AbstractCaretakerTest, metaclass=abc.ABCMeta):
+
+    json_key = 'test.json'
+    dump_key = 'data.json'
+    data_key = 'media.zip'
+    test_contents = 'test'
+
+    backend = None
+    frontend = None
+
     def __init__(self, logger: logging.Logger | None = None):
         super().__init__(logger=logger, method_name='test')
 
+        settings.CARETAKER_ADDITIONAL_BACKUP_PATHS = []
+        settings.MEDIA_ROOT = ''
+        settings.CARETAKER_BACKENDS = []
+        settings.CARETAKER_FRONTENDS = []
+        settings.CARETAKER_BACKEND = ''
+        settings.CARETAKER_FRONTEND = ''
+        settings.CARETAKER_BACKUP_BUCKET = 'caretaker_bucket'
+
+        self.bucket_name = settings.CARETAKER_BACKUP_BUCKET
+
         self.backend = BackendFactory.get_backend('Amazon S3')
         self.frontend = FrontendFactory.get_frontend('Django')
 
@@ -21,7 +41,7 @@ class AbstractDjangoS3Test(AbstractCaretakerTest, metaclass=abc.ABCMeta):
         self.data_key = 'media.zip'
         self.test_contents = 'test'
 
-        self.logger = log.get_logger('caretaker')
+        self.logger = log.get_logger('')
 
     def create_bucket(self):
         """
@@ -36,7 +56,6 @@ class AbstractDjangoS3Test(AbstractCaretakerTest, metaclass=abc.ABCMeta):
             aws_secret_access_key='fake_secret_key',
         )
 
-        self.bucket_name = 'a_test_bucket'
         self.backend.s3.create_bucket(Bucket=self.bucket_name)
 
         self.backend.s3.put_bucket_versioning(
